==> nosql-database_24.4.zip: nosql-database_24.4_20241213/content/nsuti/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"List of Examples",
                    "href":"loe.html"
                },
                {
                    "title":"List of Figures",
                    "href":"lof.html"
                },
                {
                    "title":"List of Tables",
                    "href":"lot.html"
                },
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Using Oracle NoSQL Database Migrator",
                    "href":"using-oracle-nosql-data-migrator.html",
                    "topics":[
                        {
                            "title":"Overview",
                            "href":"overview.html#GUID-44D8559E-175B-4A9E-8743-95A056BC13FD"
                        },
                        {
                            "title":"Workflow for Oracle NoSQL Database Migrator",
                            "href":"workflow-oracle-nosql-data-migrator.html"
                        },
                        {
                            "title":"Sources and Sinks",
                            "href":"sources-and-sinks.html",
                            "topics":[
                                {
                                    "title":"Supported Sources and Sinks",
                                    "href":"supported-sources-and-sinks.html"
                                },
                                {
                                    "title":"Source and Sink Security",
                                    "href":"source-and-sink-security.html"
                                },
                                {
                                    "title":"Parameters",
                                    "href":"parameters.html"
                                },
                                {
                                    "title":"Source Configuration Templates",
                                    "href":"source-configuration-templates.html#GUID-FF56A474-C6EC-40DA-8AAA-9EBA6B616630"
                                },
                                {
                                    "title":"Sink Configuration Templates",
                                    "href":"sink-configuration-templates.html#GUID-832FE48D-2A90-4DCA-95A6-40687CA7F39B"
                                },
                                {
                                    "title":"Transformation Configuration Templates",
                                    "href":"transformation-configuration-templates.html#GUID-49FE8AD3-830E-45A2-ADA8-B3048CFFD515"
                                },
                                {
                                    "title":"Mapping of DynamoDB table to Oracle NoSQL table",
                                    "href":"mapping-dynamodb-table-oracle-nosql-table.html"
                                },
                                {
                                    "title":"Oracle NoSQL to Parquet Data Type Mapping",
                                    "href":"oracle-nosql-parquet-data-type-mapping.html"
                                },
                                {
                                    "title":"Mapping of DynamoDB types to Oracle NoSQL types",
                                    "href":"mapping-dynamodb-types-oracle-nosql-types.html"
                                }
                            ]
                        },
                        {
                            "title":"Use Case Demonstrations",
                            "href":"use-case-demonstrations.html",
                            "topics":[
                                {
                                    "title":"Migrate from Oracle NoSQL Database Cloud Service to a JSON file",
                                    "href":"migrate-oracle-nosql-database-cloud-service-json-file.html"
                                },
                                {
                                    "title":"Migrate from Oracle NoSQL Database On-Premise to Oracle NoSQL Database Cloud Service",
                                    "href":"migrate-oracle-nosql-database-premise-oracle-nosql-database-cloud-service.html"
                                },
                                {
                                    "title":"Migrate from JSON file source to Oracle NoSQL Database Cloud Service",
                                    "href":"migrate-json-file-source-oracle-nosql-database-cloud-servic.html"
                                },
                                {
                                    "title":"Migrate from MongoDB JSON file to an Oracle NoSQL Database Cloud Service",
                                    "href":"migrate-mongodb-json-file-oracle-nosql-database-cloud-service.html"
                                },
                                {
                                    "title":"Migrate from DynamoDB JSON file to Oracle NoSQL Database",
                                    "href":"migrate-dynamodb-json-file-oracle-nosql-database.html"
                                },
                                {
                                    "title":"Migrate from DynamoDB JSON file in AWS S3 to an Oracle NoSQL Database Cloud Service",
                                    "href":"migrate-dynamodb-json-file-aws-s3-oracle-nosql-database-cloud-service.html"
                                },
                                {
                                    "title":"Migrate from CSV file to Oracle NoSQL Database",
                                    "href":"migrate-csv-file-oracle-nosql-database.html"
                                }
                            ]
                        },
                        {
                            "title":"Troubleshooting the Oracle NoSQL Database Migrator",
                            "href":"troubleshooting-nosql-data-migrator.html"
                        }
                    ]
                }
            ]
        }
    ]
});

==> nosql-database_25.3.zip: nosql-database_25.3_20251015/content/nsuti/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"List of Examples",
                    "href":"loe.html"
                },
                {
                    "title":"List of Figures",
                    "href":"lof.html"
                },
                {
                    "title":"List of Tables",
                    "href":"lot.html"
                },
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Using Oracle NoSQL Database Migrator",
                    "href":"using-oracle-nosql-data-migrator.html",
                    "topics":[
                        {
                            "title":"Overview",
                            "href":"overview.html#GUID-44D8559E-175B-4A9E-8743-95A056BC13FD"
                        },
                        {
                            "title":"Workflow for Oracle NoSQL Database Migrator",
                            "href":"workflow-oracle-nosql-data-migrator.html"
                        },
                        {
                            "title":"Sources and Sinks",
                            "href":"sources-and-sinks.html",
                            "topics":[
                                {
                                    "title":"Supported Sources and Sinks",
                                    "href":"supported-sources-and-sinks.html"
                                },
                                {
                                    "title":"Source and Sink Security",
                                    "href":"source-and-sink-security.html"
                                },
                                {
                                    "title":"Parameters",
                                    "href":"parameters.html"
                                },
                                {
                                    "title":"Source Configuration Templates",
                                    "href":"source-configuration-templates.html#GUID-FF56A474-C6EC-40DA-8AAA-9EBA6B616630"
                                },
                                {
                                    "title":"Sink Configuration Templates",
                                    "href":"sink-configuration-templates.html#GUID-832FE48D-2A90-4DCA-95A6-40687CA7F39B"
                                },
                                {
                                    "title":"Transformation Configuration Templates",
                                    "href":"transformation-configuration-templates.html#GUID-49FE8AD3-830E-45A2-ADA8-B3048CFFD515"
                                },
                                {
                                    "title":"Mapping of DynamoDB table to Oracle NoSQL table",
                                    "href":"mapping-dynamodb-table-oracle-nosql-table.html"
                                },
                                {
                                    "title":"Oracle NoSQL to Parquet Data Type Mapping",
                                    "href":"oracle-nosql-parquet-data-type-mapping.html"
                                },
                                {
                                    "title":"Mapping of DynamoDB types to Oracle NoSQL types",
                                    "href":"mapping-dynamodb-types-oracle-nosql-types.html"
                                }
                            ]
                        },
                        {
                            "title":"Use Case Demonstrations",
                            "href":"use-case-demonstrations.html",
                            "topics":[
                                {
                                    "title":"Migrate from Oracle NoSQL Database to a JSON file",
                                    "href":"migrate-oracle-nosql-database-json-file.html"
                                },
                                {
                                    "title":"Migrate from Oracle NoSQL Database On-Premise to Oracle NoSQL Database Cloud Service",
                                    "href":"migrate-oracle-nosql-database-premise-oracle-nosql-database-cloud-service.html"
                                },
                                {
                                    "title":"Migrate from JSON file source to Oracle NoSQL Database",
                                    "href":"migrate-json-file-source-oracle-nosql-database.html"
                                },
                                {
                                    "title":"Migrate from MongoDB JSON file to Oracle NoSQL Database",
                                    "href":"migrate-mongodb-json-file-oracle-nosql-database.html"
                                },
                                {
                                    "title":"Migrate from DynamoDB JSON file to Oracle NoSQL Database",
                                    "href":"migrate-dynamodb-json-file-oracle-nosql-database.html"
                                },
                                {
                                    "title":"Migrate from DynamoDB JSON file in AWS S3 to Oracle NoSQL Database",
                                    "href":"migrate-dynamodb-json-file-aws-s3-oracle-nosql-database.html"
                                },
                                {
                                    "title":"Migrate from CSV file to Oracle NoSQL Database",
                                    "href":"migrate-csv-file-oracle-nosql-database.html"
                                },
                                {
                                    "title":"Migrate from Oracle NoSQL Database to OCI Object Storage Using Session Token Authentication",
                                    "href":"migrate-oracle-nosql-database-oci-object-storage-using-session-token-authentication.html"
                                }
                            ]
                        },
                        {
                            "title":"Troubleshooting the Oracle NoSQL Database Migrator",
                            "href":"troubleshooting-nosql-data-migrator.html"
                        }
                    ]
                }
            ]
        }
    ]
});
